pub fn run_batch_apply(run: &BatchRun<'_>, preset_path: &Path) -> BatchSummaryExpand description
Run batch-apply: apply a preset to all images in a directory, in parallel.
pub fn run_batch_apply(run: &BatchRun<'_>, preset_path: &Path) -> BatchSummaryRun batch-apply: apply a preset to all images in a directory, in parallel.