pub struct HslChannels {
pub red: HslChannel,
pub orange: HslChannel,
pub yellow: HslChannel,
pub green: HslChannel,
pub aqua: HslChannel,
pub blue: HslChannel,
pub purple: HslChannel,
pub magenta: HslChannel,
}Expand description
HSL adjustments for all 8 color channels.
Channel order: Red (0deg), Orange (30deg), Yellow (60deg), Green (120deg), Aqua (180deg), Blue (240deg), Purple (270deg), Magenta (330deg).
Fields
red: HslChannelHSL adjustment for the red channel (~0°).
orange: HslChannelHSL adjustment for the orange channel (~30°).
yellow: HslChannelHSL adjustment for the yellow channel (~60°).
green: HslChannelHSL adjustment for the green channel (~120°).
aqua: HslChannelHSL adjustment for the aqua channel (~180°).
blue: HslChannelHSL adjustment for the blue channel (~240°).
purple: HslChannelHSL adjustment for the purple channel (~270°).
magenta: HslChannelHSL adjustment for the magenta channel (~330°).
Implementations
Sourceimpl HslChannels
impl HslChannels
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns true if all channels are at default (zero) values.
Sourcepub fn hue_shifts(&self) -> [f32; 8]
pub fn hue_shifts(&self) -> [f32; 8]
Extract hue shifts as an array ordered by channel index.
Sourcepub fn saturation_shifts(&self) -> [f32; 8]
pub fn saturation_shifts(&self) -> [f32; 8]
Extract saturation shifts as an array ordered by channel index.
Sourcepub fn luminance_shifts(&self) -> [f32; 8]
pub fn luminance_shifts(&self) -> [f32; 8]
Extract luminance shifts as an array ordered by channel index.